@@ -2,15 +2,14 @@ import argparse
 
 
 class NoOpAction(argparse.Action):
-
     def __init__(
-        self,
-        option_strings,
-        dest,
-        default=None,
-        required=False,
-        help=None,
-        metavar=None
+            self,
+            option_strings,
+            dest,
+            default=None,
+            required=False,
+            help=None,
+            metavar=None,
     ):
         super(NoOpAction, self).__init__(
             option_strings=option_strings,
@@ -19,8 +18,14 @@ class NoOpAction(argparse.Action):
             const=None,
             default=default,
             required=required,
-            help=help
+            help=help,
         )
 
-    def __call__(self, parser, namespace, values, option_string=None):
+    def __call__(
+            self,
+            parser,
+            namespace,
+            values,
+            option_string=None,
+    ):
         pass
